@@ -666,493 +666,6 @@ Bool XNVCtrlSelectNotify (
     return True;
 }
 
-
-Bool XNVCTRLQueryDDCCILutSize (
-    Display *dpy,
-    int screen,
-    unsigned int display_mask,
-    unsigned int *red_entries,
-    unsigned int *green_entries,
-    unsigned int *blue_entries,
-    unsigned int *red_bits_per_entries,
-    unsigned int *green_bits_per_entries,
-    unsigned int *blue_bits_per_entries
-) {
-    XExtDisplayInfo *info = find_display (dpy);
-    xnvCtrlQueryDDCCILutSizeReply rep;
-    xnvCtrlQueryDDCCILutSizeReq *req;
-    unsigned int buf[6];
-    Bool exists;
-    
-    if(!XextHasExtension(info))
-        return False;
-
-    XNVCTRLCheckExtension (dpy, info, False);
-
-    LockDisplay (dpy);
-
-    GetReq (nvCtrlQueryDDCCILutSize, req);
-    req->reqType = info->codes->major_opcode;
-    req->nvReqType = X_nvCtrlQueryDDCCILutSize;
-    req->screen = screen;
-    req->display_mask = display_mask;
-
-    if (!_XReply(dpy, (xReply *) &rep, 0, xFalse)) {
-        UnlockDisplay (dpy);
-        SyncHandle ();
-        return False;
-    }
-
-    _XRead(dpy, (char *)(&buf), 24);
-
-    *red_entries = buf[0];
-    *green_entries = buf[1];
-    *blue_entries = buf[2];
-    *red_bits_per_entries = buf[3];
-    *green_bits_per_entries = buf[4];
-    *blue_bits_per_entries = buf[5];
-    
-    UnlockDisplay (dpy);
-    SyncHandle ();
-    exists = rep.flags;
-    return exists;
-}
-
-
-Bool XNVCTRLQueryDDCCISinglePointLutOperation (
-    Display *dpy,
-    int screen,
-    unsigned int display_mask,
-    unsigned int offset,
-    unsigned int *red_value,
-    unsigned int *green_value,
-    unsigned int *blue_value
-) {
-    XExtDisplayInfo *info = find_display (dpy);
-    xnvCtrlQueryDDCCISinglePointLutOperationReply rep;
-    xnvCtrlQueryDDCCISinglePointLutOperationReq *req;
-    unsigned int buf[4];
-    Bool exists;
-    
-    if(!XextHasExtension(info))
-        return False;
-
-    XNVCTRLCheckExtension (dpy, info, False);
-
-    LockDisplay (dpy);
-
-    GetReq (nvCtrlQueryDDCCISinglePointLutOperation, req);
-    req->reqType = info->codes->major_opcode;
-    req->nvReqType = X_nvCtrlQueryDDCCISinglePointLutOperation;
-    req->screen = screen;
-    req->display_mask = display_mask;
-    req->offset = offset;
-    
-    if (!_XReply(dpy, (xReply *) &rep, 0, xFalse)) {
-        UnlockDisplay (dpy);
-        SyncHandle ();
-        return False;
-    }
-
-    _XRead(dpy, (char *)(&buf), 12);
-
-    *red_value = buf[0];
-    *green_value = buf[1];
-    *blue_value = buf[2];
-    
-    UnlockDisplay (dpy);
-    SyncHandle ();
-    
-    exists=rep.flags;
-    return exists;
-}
-
-
-Bool XNVCTRLSetDDCCISinglePointLutOperation (
-    Display *dpy,
-    int screen,
-    unsigned int display_mask,
-    unsigned int offset,
-    unsigned int red_value,
-    unsigned int green_value,
-    unsigned int blue_value
-) { 
-    XExtDisplayInfo *info = find_display (dpy);
-    xnvCtrlSetDDCCISinglePointLutOperationReply rep;
-    xnvCtrlSetDDCCISinglePointLutOperationReq *req;
-    Bool success;
-    
-    if(!XextHasExtension(info))
-        return False;
-
-    XNVCTRLCheckExtension (dpy, info, False);
-
-    LockDisplay (dpy);
-    GetReq (nvCtrlSetDDCCISinglePointLutOperation, req);
-    req->reqType = info->codes->major_opcode;
-    req->nvReqType = X_nvCtrlSetDDCCISinglePointLutOperation;
-    req->screen = screen;
-    req->display_mask = display_mask;
-    req->offset = offset;
-    req->red_value = red_value;
-    req->green_value = green_value;
-    req->blue_value = blue_value;
-    
-    if (!_XReply (dpy, (xReply *) &rep, 0, False)) {
-        UnlockDisplay (dpy);
-        SyncHandle ();
-        return False;
-    }
-    UnlockDisplay (dpy);
-    SyncHandle ();
-    
-    success = rep.flags;
-    return success;
-}
-
-
-Bool XNVCTRLQueryDDCCIBlockLutOperation (
-    Display *dpy,
-    int screen,
-    unsigned int display_mask,
-    unsigned int color, // NV_CTRL_DDCCI_RED_LUT, NV_CTRL_DDCCI_GREEN_LUT, NV_CTRL_DDCCI_BLUE_LUT
-    unsigned int offset,
-    unsigned int size,
-    unsigned int **value
-) {
-    XExtDisplayInfo *info = find_display (dpy);
-    xnvCtrlQueryDDCCIBlockLutOperationReply rep;
-    xnvCtrlQueryDDCCIBlockLutOperationReq *req;
-    Bool exists;
-    int length, slop;
-    char *ptr;
-
-    if(!XextHasExtension(info))
-        return False;
-
-    XNVCTRLCheckExtension (dpy, info, False);
-
-    LockDisplay (dpy);
-    GetReq (nvCtrlQueryDDCCIBlockLutOperation, req);
-    req->reqType = info->codes->major_opcode;
-    req->nvReqType = X_nvCtrlQueryDDCCIBlockLutOperation;
-    req->screen = screen;
-    req->display_mask = display_mask;
-    req->color=color;
-    req->offset=offset;
-    req->size=size;
-    if (!_XReply (dpy, (xReply *) &rep, 0, False)) {
-        UnlockDisplay (dpy);
-        SyncHandle ();
-        return False;
-    }
-    length = rep.length;
-    slop = rep.num_bytes & 3;
-    ptr = (char *) Xmalloc(rep.num_bytes);
-    if (! ptr) {
-        _XEatData(dpy, length);
-        UnlockDisplay (dpy);
-        SyncHandle ();
-        return False;
-    } else {
-        _XRead(dpy, (char *) ptr, rep.num_bytes);
-        if (slop) _XEatData(dpy, 4-slop);
-    }
-    exists = rep.flags;
-    if(exists) {
-        *value=(unsigned int *)ptr;
-    }
-    UnlockDisplay (dpy);
-    SyncHandle ();
-    return exists;
-}
-
-
-Bool XNVCTRLSetDDCCIBlockLutOperation (
-    Display *dpy,
-    int screen,
-    unsigned int display_mask,
-    unsigned int color, // NV_CTRL_DDCCI_RED_LUT, NV_CTRL_DDCCI_GREEN_LUT, NV_CTRL_DDCCI_BLUE_LUT
-    unsigned int offset,
-    unsigned int size,
-    unsigned int *value
-) {
-    XExtDisplayInfo *info = find_display (dpy);
-    xnvCtrlSetDDCCIBlockLutOperationReq *req;
-    xnvCtrlSetDDCCIBlockLutOperationReply rep;
-    Bool success;
-    
-    if(!XextHasExtension(info))
-        return False;
-
-    XNVCTRLCheckExtension (dpy, info, False);
-
-    LockDisplay (dpy);
-    GetReq (nvCtrlSetDDCCIBlockLutOperation, req);
-    req->reqType = info->codes->major_opcode;
-    req->nvReqType = X_nvCtrlSetDDCCIBlockLutOperation;
-    req->screen = screen;
-    req->display_mask = display_mask;
-    req->color = color;
-    req->offset = offset;
-    req->size = size;
-    req->num_bytes = size << 2;
-    req->length += (req->num_bytes + 3) >> 2;
-    Data(dpy, (char *)value, req->num_bytes );
-    
-    if (!_XReply (dpy, (xReply *) &rep, 0, False)) {
-        UnlockDisplay (dpy);
-        SyncHandle ();
-        return False;
-    }
-    UnlockDisplay (dpy);
-    SyncHandle ();
-    
-    success = rep.flags;
-    return success;
-}
-
-
-Bool XNVCTRLSetDDCCIRemoteProcedureCall (
-    Display *dpy,
-    int screen,
-    unsigned int display_mask,
-    unsigned int offset,
-    unsigned int size,
-    unsigned int *red_lut,
-    unsigned int *green_lut,
-    unsigned int *blue_lut,
-    unsigned int *increment
-) {
-    XExtDisplayInfo *info = find_display (dpy);
-    xnvCtrlSetDDCCIRemoteProcedureCallReq *req;
-    xnvCtrlSetDDCCIRemoteProcedureCallReply rep;
-    unsigned int nbytes;
-    Bool success;
-    
-    if(!XextHasExtension(info))
-        return False;
-
-    XNVCTRLCheckExtension (dpy, info, False);
-
-    LockDisplay (dpy);
-    GetReq (nvCtrlSetDDCCIRemoteProcedureCall, req);
-    req->reqType = info->codes->major_opcode;
-    req->nvReqType = X_nvCtrlSetDDCCIRemoteProcedureCall;
-    req->screen = screen;
-    req->display_mask = display_mask;
-    req->size = size;
-    nbytes= size << 2;
-    req->num_bytes = nbytes * 4;
-    req->length += (req->num_bytes + 3) >> 2;
-    req->offset = offset;
-    Data(dpy, (char *)red_lut, nbytes );
-    Data(dpy, (char *)green_lut, nbytes );
-    Data(dpy, (char *)blue_lut, nbytes );
-    Data(dpy, (char *)increment, nbytes );
-    
-    if (!_XReply (dpy, (xReply *) &rep, 0, False)) {
-        UnlockDisplay (dpy);
-        SyncHandle ();
-        return False;
-    }
-    UnlockDisplay (dpy);
-    SyncHandle ();
-    
-    success = rep.flags;
-    return success;
-}
-
-/* XXXAlternative: Instead of getting the manufacturer string from the server, 
- * get the manufacturer Id instead, and have controller_manufacturer assigned 
- * to a static string that would not need to be malloc'ed and freed.
- */
-Bool XNVCTRLQueryDDCCIDisplayControllerType (
-    Display *dpy,
-    int screen,
-    unsigned int display_mask,
-    unsigned char **controller_manufacturer,
-    unsigned int *controller_type
-)
-{
-    XExtDisplayInfo *info = find_display (dpy);
-    xnvCtrlQueryDDCCIDisplayControllerTypeReply rep;
-    xnvCtrlQueryDDCCIDisplayControllerTypeReq *req;
-    Bool exists;
-    int length, numbytes, slop;
-    char *ptr;
-
-    if(!XextHasExtension(info))
-        return False;
-
-    XNVCTRLCheckExtension (dpy, info, False);
-
-    LockDisplay (dpy);
-    GetReq (nvCtrlQueryDDCCIDisplayControllerType, req);
-    req->reqType = info->codes->major_opcode;
-    req->nvReqType = X_nvCtrlQueryDDCCIDisplayControllerType;
-    req->screen = screen;
-    req->display_mask = display_mask;
-    if (!_XReply (dpy, (xReply *) &rep, 0, False)) {
-        UnlockDisplay (dpy);
-        SyncHandle ();
-        return False;
-    }
-    length = rep.length;
-    numbytes = rep.size;
-    slop = numbytes & 3;
-    ptr = (char *) Xmalloc(numbytes);
-    if (! ptr) {
-        _XEatData(dpy, length);
-        UnlockDisplay (dpy);
-        SyncHandle ();
-        return False;
-    } else {
-        _XRead(dpy, (char *) ptr, numbytes);
-        if (slop) _XEatData(dpy, 4-slop);
-    }
-    exists = rep.flags;
-    if(exists) {
-        *controller_type=rep.controller_type;
-        *controller_manufacturer=ptr;
-    }
-    UnlockDisplay (dpy);
-    SyncHandle ();
-    return exists;
-}
-
-
-Bool NVCTRLQueryDDCCICapabilities (
-    Display *dpy,
-    int screen,
-    unsigned int display_mask,
-    unsigned int **nvctrl_vcp_supported,
-    unsigned int **possible_values_offset,
-    unsigned int **possible_values_size,
-    unsigned int **nvctrl_vcp_possible_values,
-    unsigned int **nvctrl_string_vcp_supported
-)
-{
-    XExtDisplayInfo *info = find_display (dpy);
-    xnvCtrlQueryDDCCICapabilitiesReply rep;
-    xnvCtrlQueryDDCCICapabilitiesReq *req;
-    Bool exists=1;
-    int length, numbytes, slop;
-    char *ptr, *p;
-    int len1, len2, len3, len4, len5;
-     
-    *nvctrl_vcp_supported=*nvctrl_vcp_possible_values=*possible_values_offset=*possible_values_size=*nvctrl_string_vcp_supported=NULL;
-   
-    if(!XextHasExtension(info))
-        return False;
-
-    XNVCTRLCheckExtension (dpy, info, False);
-
-    LockDisplay (dpy);
-    
-    GetReq (nvCtrlQueryDDCCICapabilities, req);
-    req->reqType = info->codes->major_opcode;
-    req->nvReqType = X_nvCtrlQueryDDCCICapabilities; 
-    
-    req->screen = screen;
-    req->display_mask = display_mask;
-    if (!_XReply (dpy, (xReply *) &rep, 0, False)) {
-        UnlockDisplay (dpy);
-        SyncHandle ();
-        return False;
-    }
-    length = rep.length;
-    numbytes = rep.num_bytes;
-    slop = numbytes & 3;
-    ptr = (char *) Xmalloc(numbytes);
-    if (! ptr) {
-        _XEatData(dpy, length);
-        UnlockDisplay (dpy);
-        SyncHandle ();
-        return False;
-    } else {
-        _XRead(dpy, (char *) ptr, numbytes);
-        if (slop) _XEatData(dpy, 4-slop);
-    }
-    exists = rep.flags;
-    if(exists) {
-        p = ptr;
-        len1 = len2 = len3 = (NV_CTRL_DDCCI_LAST_VCP+1) << 2 ;
-        len4 = rep.possible_val_len << 2;
-        len5 = (NV_CTRL_STRING_LAST_ATTRIBUTE+1) << 2;
-        *nvctrl_vcp_supported=(unsigned int *) Xmalloc(len1);
-        *possible_values_offset=(unsigned int *) Xmalloc(len2);
-        *possible_values_size=(unsigned int *) Xmalloc(len3);
-        if(len4)
-            *nvctrl_vcp_possible_values=(unsigned int *) Xmalloc(len4);
-        *nvctrl_string_vcp_supported=(unsigned int *) Xmalloc(len5);
-        memcpy((char*)*nvctrl_vcp_supported, p, len1);         p += len1;
-        memcpy((char*)*possible_values_offset, p, len2);       p += len2;
-        memcpy((char*)*possible_values_size, p, len3);         p += len3;
-        if(len4) {
-           memcpy((char*)*nvctrl_vcp_possible_values, p, len4);   p += len4;
-        }
-        memcpy((char*)*nvctrl_string_vcp_supported, p, len5); 
-    }
-    free(ptr);
-    UnlockDisplay (dpy);
-    SyncHandle ();
-    return exists;
-}
-
-Bool XNVCTRLQueryDDCCITimingReport (
-    Display *dpy,
-    int screen,
-    unsigned int display_mask,
-    unsigned int *sync_freq_out_range, 
-    unsigned int *unstable_count,
-    unsigned int *positive_h_sync,
-    unsigned int *positive_v_sync,
-    unsigned int *h_freq,
-    unsigned int *v_freq
-) {
-    XExtDisplayInfo *info = find_display (dpy);
-    xnvCtrlQueryDDCCITimingReportReply rep;
-    xnvCtrlQueryDDCCITimingReportReq *req;
-    unsigned int buf[6];
-    Bool exists;
-    
-    if(!XextHasExtension(info))
-        return False;
-
-    XNVCTRLCheckExtension (dpy, info, False);
-
-    LockDisplay (dpy);
-
-    GetReq (nvCtrlQueryDDCCITimingReport, req);
-    req->reqType = info->codes->major_opcode;
-    req->nvReqType = X_nvCtrlQueryDDCCITimingReport;
-    req->screen = screen;
-    req->display_mask = display_mask;
-
-    if (!_XReply(dpy, (xReply *) &rep, 0, xFalse)) {
-        UnlockDisplay (dpy);
-        SyncHandle ();
-        return False;
-    }
-
-    _XRead(dpy, (char *)(&buf), 24);
-    
-    exists = rep.flags;
-    
-    *sync_freq_out_range = buf[0];
-    *unstable_count = buf[1];
-    *positive_h_sync = buf[2];
-    *positive_v_sync = buf[3];
-    *h_freq = buf[4];
-    *v_freq = buf[5];
-    
-    UnlockDisplay (dpy);
-    SyncHandle ();
-
-    return exists;
-}
-
 Bool XNVCTRLQueryTargetBinaryData (
     Display *dpy,
     int target_type,
@@ -1192,7 +705,7 @@ Bool XNVCTRLQueryTargetBinaryData (
     length = rep.length;
     numbytes = rep.n;
     slop = numbytes & 3;
-    *ptr = (char *) Xmalloc(numbytes);
+    *ptr = (unsigned char *) Xmalloc(numbytes);
     if (! *ptr) {
         _XEatData(dpy, length);
         UnlockDisplay (dpy);
